==> seacas-for-vtk-20190111-7.15f-master.zip: seacas-for-vtk-20190111-7.15f-master/docs/apr_html/files_dup.js <==
var files_dup =
[
    [ "apr_aprepro.cc", "apr__aprepro_8cc.html", "apr__aprepro_8cc" ],
    [ "apr_array.cc", "apr__array_8cc.html", "apr__array_8cc" ],
    [ "apr_array.h", "apr__array_8h.html", "apr__array_8h" ],
    [ "apr_builtin.cc", "apr__builtin_8cc.html", "apr__builtin_8cc" ],
    [ "apr_builtin.h", "apr__builtin_8h.html", "apr__builtin_8h" ],
    [ "apr_exodus.cc", "apr__exodus_8cc.html", null ],
    [ "apr_getline_int.h", "apr__getline__int_8h.html", "apr__getline__int_8h" ],
    [ "apr_init.cc", "apr__init_8cc.html", "apr__init_8cc" ],
    [ "apr_parser.cc", "apr__parser_8cc.html", "apr__parser_8cc" ],
    [ "apr_scanner.cc", "apr__scanner_8cc.html", "apr__scanner_8cc" ],
    [ "apr_scanner.h", "apr__scanner_8h.html", "apr__scanner_8h" ],
    [ "apr_stats.cc", "apr__stats_8cc.html", null ],
    [ "apr_stats.h", "apr__stats_8h.html", [
      [ "Stats", "classSEAMS_1_1Stats.html", "classSEAMS_1_1Stats" ]
    ] ],
    [ "apr_test.cc", "apr__test_8cc.html", "apr__test_8cc" ],
    [ "apr_tokenize.cc", "apr__tokenize_8cc.html", null ],
    [ "apr_tokenize.h", "apr__tokenize_8h.html", "apr__tokenize_8h" ],
    [ "apr_units.cc", "apr__units_8cc.html", "apr__units_8cc" ],
    [ "apr_util.cc", "apr__util_8cc.html", "apr__util_8cc" ],
    [ "apr_util.h", "apr__util_8h.html", "apr__util_8h" ],
    [ "aprepro.h", "aprepro_8h.html", "aprepro_8h" ],
    [ "aprepro_parser.h", "aprepro__parser_8h.html", "aprepro__parser_8h" ],
    [ "FlexLexer.h", "FlexLexer_8h.html", "FlexLexer_8h" ],
    [ "init_structs.h", "init__structs_8h.html", [
      [ "init", "structinit.html", "structinit" ],
      [ "init_d", "structinit__d.html", "structinit__d" ],
      [ "init_dd", "structinit__dd.html", "structinit__dd" ],
      [ "init_cd", "structinit__cd.html", "structinit__cd" ],
      [ "init_ddd", "structinit__ddd.html", "structinit__ddd" ],
      [ "init_dddd", "structinit__dddd.html", "structinit__dddd" ],
      [ "init_dddddd", "structinit__dddddd.html", "structinit__dddddd" ],
      [ "init_ccc", "structinit__ccc.html", "structinit__ccc" ],
      [ "init_cc", "structinit__cc.html", "structinit__cc" ],
      [ "init_c", "structinit__c.html", "structinit__c" ],
      [ "init_a", "structinit__a.html", "structinit__a" ],
      [ "str_init", "structstr__init.html", "structstr__init" ],
      [ "str_c_init", "structstr__c__init.html", "structstr__c__init" ],
      [ "str_d_init", "structstr__d__init.html", "structstr__d__init" ],
      [ "str_a_init", "structstr__a__init.html", "structstr__a__init" ],
      [ "str_dcc_init", "structstr__dcc__init.html", "structstr__dcc__init" ],
      [ "str_cc_init", "structstr__cc__init.html", "structstr__cc__init" ],
      [ "str_ccc_init", "structstr__ccc__init.html", "structstr__ccc__init" ],
      [ "array_c_init", "structarray__c__init.html", "structarray__c__init" ],
      [ "array_cc_init", "structarray__cc__init.html", "structarray__cc__init" ],
      [ "array_cd_init", "structarray__cd__init.html", "structarray__cd__init" ],
      [ "array_dd_init", "structarray__dd__init.html", "structarray__dd__init" ],
      [ "array_d_init", "structarray__d__init.html", "structarray__d__init" ],
      [ "array_a_init", "structarray__a__init.html", "structarray__a__init" ],
      [ "var_init", "structvar__init.html", "structvar__init" ],
      [ "svar_init", "structsvar__init.html", "structsvar__init" ]
    ] ],
    [ "strings.cc", "strings_8cc.html", "strings_8cc" ]
];

==> seacas-for-vtk-20191226-7.24f-master.zip: seacas-for-vtk-20191226-7.24f-master/docs/apr_html/files_dup.js <==
var files_dup =
[
    [ "apr_aprepro.cc", "apr__aprepro_8cc.html", "apr__aprepro_8cc" ],
    [ "apr_array.cc", "apr__array_8cc.html", "apr__array_8cc" ],
    [ "apr_array.h", "apr__array_8h.html", "apr__array_8h" ],
    [ "apr_builtin.cc", "apr__builtin_8cc.html", "apr__builtin_8cc" ],
    [ "apr_builtin.h", "apr__builtin_8h.html", "apr__builtin_8h" ],
    [ "apr_exodus.cc", "apr__exodus_8cc.html", null ],
    [ "apr_getline_int.h", "apr__getline__int_8h.html", "apr__getline__int_8h" ],
    [ "apr_init.cc", "apr__init_8cc.html", "apr__init_8cc" ],
    [ "apr_parser.cc", "apr__parser_8cc.html", "apr__parser_8cc" ],
    [ "apr_scanner.cc", "apr__scanner_8cc.html", "apr__scanner_8cc" ],
    [ "apr_scanner.h", "apr__scanner_8h.html", "apr__scanner_8h" ],
    [ "apr_stats.cc", "apr__stats_8cc.html", null ],
    [ "apr_stats.h", "apr__stats_8h.html", [
      [ "Stats", "classSEAMS_1_1Stats.html", "classSEAMS_1_1Stats" ]
    ] ],
    [ "apr_test.cc", "apr__test_8cc.html", "apr__test_8cc" ],
    [ "apr_tokenize.cc", "apr__tokenize_8cc.html", null ],
    [ "apr_tokenize.h", "apr__tokenize_8h.html", "apr__tokenize_8h" ],
    [ "apr_units.cc", "apr__units_8cc.html", "apr__units_8cc" ],
    [ "apr_util.cc", "apr__util_8cc.html", "apr__util_8cc" ],
    [ "apr_util.h", "apr__util_8h.html", "apr__util_8h" ],
    [ "aprepro.h", "aprepro_8h.html", "aprepro_8h" ],
    [ "aprepro_parser.h", "aprepro__parser_8h.html", "aprepro__parser_8h" ],
    [ "FlexLexer.h", "FlexLexer_8h.html", "FlexLexer_8h" ],
    [ "init_structs.h", "init__structs_8h.html", [
      [ "init", "structinit.html", "structinit" ],
      [ "init_d", "structinit__d.html", "structinit__d" ],
      [ "init_dd", "structinit__dd.html", "structinit__dd" ],
      [ "init_cd", "structinit__cd.html", "structinit__cd" ],
      [ "init_ddd", "structinit__ddd.html", "structinit__ddd" ],
      [ "init_dddd", "structinit__dddd.html", "structinit__dddd" ],
      [ "init_dddddd", "structinit__dddddd.html", "structinit__dddddd" ],
      [ "init_ccc", "structinit__ccc.html", "structinit__ccc" ],
      [ "init_cc", "structinit__cc.html", "structinit__cc" ],
      [ "init_c", "structinit__c.html", "structinit__c" ],
      [ "init_a", "structinit__a.html", "structinit__a" ],
      [ "str_init", "structstr__init.html", "structstr__init" ],
      [ "str_c_init", "structstr__c__init.html", "structstr__c__init" ],
      [ "str_d_init", "structstr__d__init.html", "structstr__d__init" ],
      [ "str_a_init", "structstr__a__init.html", "structstr__a__init" ],
      [ "str_dcc_init", "structstr__dcc__init.html", "structstr__dcc__init" ],
      [ "str_cc_init", "structstr__cc__init.html", "structstr__cc__init" ],
      [ "str_ccc_init", "structstr__ccc__init.html", "structstr__ccc__init" ],
      [ "array_c_init", "structarray__c__init.html", "structarray__c__init" ],
      [ "array_cc_init", "structarray__cc__init.html", "structarray__cc__init" ],
      [ "array_cd_init", "structarray__cd__init.html", "structarray__cd__init" ],
      [ "array_ddd_init", "structarray__ddd__init.html", "structarray__ddd__init" ],
      [ "array_dd_init", "structarray__dd__init.html", "structarray__dd__init" ],
      [ "array_d_init", "structarray__d__init.html", "structarray__d__init" ],
      [ "array_a_init", "structarray__a__init.html", "structarray__a__init" ],
      [ "var_init", "structvar__init.html", "structvar__init" ],
      [ "svar_init", "structsvar__init.html", "structsvar__init" ]
    ] ],
    [ "strings.cc", "strings_8cc.html", "strings_8cc" ],
    [ "terminal_color.h", "terminal__color_8h.html", "terminal__color_8h" ]
];
